import axios from 'axios'
import downloadjs from 'downloadjs'
import { getStore, USR } from '../utils/userinfo'
interface LoginData{
    name: string
    password: string
}
const instance = axios.create({
    timeout:15000
})
instance.interceptors.request.use((config)=>{
    if(config.url !== '/api/admin/login'){
        config.headers=  {
            'auth-Token':store?store.token?store.token:'':''
        }
        return config
    }else{
        return config
    }
})
instance.interceptors.response.use((response)=>{
    // console.log('ee',response)
    return response.data
})

const store = getStore<USR<any>>('mining-manager')
export const doLogin = async (data:LoginData) => {
    return instance.post('/api/admin/login',
        data
    ).then(res=>{
        console.log(res.headers);
        
        if(res.data.data.isSucc){
            return res.headers['auth-token']
        }
    }).catch((err)=>{
        console.log(err);
    })
}


export const getPlatList = async()=>{
    return instance.get('/api/admin/plat-list',)
}
export const getNodeList = async(params:{id:string})=>{
    return instance.get('/api/admin/node-list',{params})
}
export const getPoolList = async(params:{id:string})=>{
    return instance.get('/api/admin/pool-list',{params})
}

export interface GetTransListParams{
    platId?:number
    status?:number
    start?:number
    end?:number
    addr?:string
    page?:number
    pageSize?:number
}

export const getTransList = async(params:GetTransListParams)=>{
    params.page?params.page:params.page=1
    params.pageSize?params.pageSize:params.pageSize=10
    return instance.get('/api/admin/trans-list',{
        params:params
    }).then(res=>{
        return res.data
    })
}

export const downloadTxt = async(params:GetTransListParams)=>{
    return instance.get('/download/unsigntxs',{
        params: params
    }).then(async res=>{
            try{
                await downloadjs(res.data)
                return{
                    status:'success', 
                    message:'download action is finished'
                }
            }catch(err){
                console.log('下载出错了',err);
            }
        return
    }).catch((err:any)=>{
        return{
            status:'error',
            message:err.response.data.message
        }
    })
  
}
export default instance